# apipipeline
## Api Request Pipeline
A package containing a class that assists large looping api requests.
Most useful when data from the requests are needed to make the next request. 
Automatically watches api request limits, and processes requests accordingly.